<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    SuperNews
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function supernews_body_classes( $classes ) {

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( in_array( get_theme_mod( 'theme_layout' ), array( '1c', 'narrow-2' ) ) ) {
		$classes[] = 'layout-narrow';
	}

	return $classes;
}
add_filter( 'body_class', 'supernews_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function supernews_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	return $classes;
}
add_filter( 'post_class', 'supernews_post_classes' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function supernews_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'supernews_excerpt_more' );

/**
 * Override the default options.php location.
 *
 * @since  1.0.0
 */
function supernews_location_override() {
	return array( 'admin/options/options.php' );
}
add_filter( 'options_framework_location', 'supernews_location_override' );

/**
 * Change the theme options text.
 *
 * @since  1.0.0
 * @param  array $menu
 */
function supernews_theme_options_text( $menu ) {
	$menu['page_title'] = '';
	$menu['menu_title'] = __( 'Theme Settings', 'supernews' );

	return $menu;
}
add_filter( 'optionsframework_menu', 'supernews_theme_options_text' );

/**
 * Custom RSS feed url.
 *
 * @since  1.0.0
 * @return string
 */
function supernews_feed_url( $output, $feed ) {

	// Get the custom rss feed url.
	$url = of_get_option( 'supernews_feedburner_url' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( !empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
add_filter( 'feed_link', 'supernews_feed_url', 10, 2 );

/**
 * Move textarea comment field to the top.
 *
 * @since  1.0.0
 */
function supernews_move_textarea( $input = array () ) {
	static $textarea = '';

	if ( 'comment_form_defaults' === current_filter() ) {
		$textarea = $input['comment_field'];
		$input['comment_field'] = '';
		return $input;
	}
	if ( is_singular( 'post' ) || is_page() ) {
		print $textarea;
	}
}
add_action( 'comment_form_defaults', 'supernews_move_textarea' );
add_action( 'comment_form_top', 'supernews_move_textarea' );

/**
 * Custom comment form fields.
 *
 * @since  1.0.0
 * @param  array $fields
 * @return array
 */
function supernews_comment_form_fields( $fields, $args = array() ) {

	$args = wp_parse_args( $args );
	if ( ! isset( $args['format'] ) )
		$args['format'] = current_theme_supports( 'html5', 'comment-form' ) ? 'html5' : 'xhtml';

	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );
	$aria_req  = ( $req ? " aria-required='true'" : '' );
	$html5     = 'html5' === $args['format'];

	$fields['author'] = '<p class="comment-form-author">' . '<label for="author"><i class="fa fa-user"></i> ' . __( 'Name', 'supernews' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' . '<input class="txt" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';

	$fields['email'] = '<p class="comment-form-email"><label for="email"><i class="fa fa-envelope"></i> ' . __( 'Email', 'supernews' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' . '<input class="txt" id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';

	$fields['url'] = '<p class="comment-form-url"><label for="url"><i class="fa fa-link"></i> ' . __( 'Website', 'supernews' ) . '</label> ' . '<input class="txt" id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /></p>';

	return $fields;

}
add_filter( 'comment_form_default_fields', 'supernews_comment_form_fields' );

/**
 * Add custom attribute 'itempro="image"' to the post thumbnail.
 *
 * @since  1.0.0
 * @param  array  $attr
 * @return array
 */
function supernews_img_attr( $attr ) {
    $attr['itemprop'] = 'image';
    return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'supernews_img_attr', 10, 2 );

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 *
 * @since 1.0.0
 */
function supernews_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );
}
add_action( 'init', 'supernews_remove_theme_layout_metabox', 11 );

/**
 * Add post type 'post' support for page sidebars plugin.
 *
 * @since  1.0.0
 */
function supernews_page_sidebar_plugin() {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if ( is_plugin_active( 'simple-page-sidebars/simple-page-sidebars.php' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'supernews_page_sidebar_plugin' );

/**
 * Filter the posts on category page.
 * Split the featured posts and the standard posts.
 *
 * @since  1.0.0
 */
function supernews_category_posts_filter( $query ) {

	$tag = of_get_option( 'supernews_featured_tag' );

	if ( $tag !== '' ) {

		if ( ! is_admin() && $query->is_main_query() ) {
			if ( $query->is_category() ) {
				$query->set( 'tag__not_in', $tag );
			}
		}

	}

}
add_action( 'pre_get_posts', 'supernews_category_posts_filter' );

/**
 * Register custom contact info fields.
 *
 * @since  1.0.0
 * @param  array $contactmethods
 * @return array
 */
function supernews_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']   = __( 'Twitter URL', 'supernews' );
	$contactmethods['facebook']  = __( 'Facebook URL', 'supernews' );
	$contactmethods['gplus']     = __( 'Google Plus URL', 'supernews' );
	$contactmethods['linkedin']  = __( 'LinkedIn URL', 'supernews' );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'supernews_contact_info_fields' );

/**
 * Custom <header> attributes
 */
function supernews_attr_header( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_header',  'supernews_attr_header' );

/**
 * Custom <footer> attributes
 */
function supernews_attr_footer( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_footer', 'supernews_attr_footer' );

/**
 * Custom <main> attributes
 */
function supernews_attr_main( $attr ) {
	unset( $attr['class'] );
	unset( $attr['role'] );

	if ( isset( $attr['itemprop'] ) ) {
		$attr['itemtype']  = 'http://schema.org/WebPageElement';
		$attr['itemscope'] = 'itemscope';
	}

	return $attr;
}
add_filter( 'hybrid_attr_content', 'supernews_attr_main' );

/**
 * Custom sidebar attributes
 */
function supernews_attr_sidebar( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_sidebar', 'supernews_attr_sidebar' );

/**
 * Custom <nav> attributes
 */
function supernews_attr_menu( $attr ) {
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_menu', 'supernews_attr_menu' );

/**
 * Custom site-title
 */
function supernews_attr_site_title( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_site-title', 'supernews_attr_site_title' );

/**
 * Custom site-description
 */
function supernews_attr_site_description( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_site-description', 'supernews_attr_site_description' );

/**
 * Custom post <article> attributes
 */
function supernews_attr_post( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_post', 'supernews_attr_post' );

/**
 * Custom entry-title
 */
function supernews_attr_entry_title( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );
	unset( $attr['role'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-title', 'supernews_attr_entry_title' );

/**
 * Custom entry-author
 */
function supernews_attr_entry_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-author', 'supernews_attr_entry_author' );

/**
 * Custom entry-published
 */
function supernews_attr_entry_published( $attr ) {
	unset( $attr['class'] );
	unset( $attr['content'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-published', 'supernews_attr_entry_published' );

/**
 * Custom entry-content
 */
function supernews_attr_entry_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-content', 'supernews_attr_entry_content' );

/**
 * Custom entry-summary
 */
function supernews_attr_entry_summary( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-summary', 'supernews_attr_entry_summary' );

/**
 * Custom entry-terms
 */
function supernews_attr_entry_terms( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_entry-terms', 'supernews_attr_entry_terms' );

/**
 * Comments
 */
function supernews_attr_comment( $attr ) {
	unset( $attr['id'] );
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment', 'supernews_attr_comment' );

/**
 * Custom comment-author
 */
function supernews_attr_comment_author( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-author', 'supernews_attr_comment_author' );

/**
 * Custom comment-published
 */
function supernews_attr_comment_published( $attr ) {
	unset( $attr['datetime'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-published', 'supernews_attr_comment_published' );

/**
 * Custom comment-permalink
 */
function supernews_attr_comment_permalink( $attr ) {
	unset( $attr['href'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-permalink', 'supernews_attr_comment_permalink' );

/**
 * Custom comment-content
 */
function supernews_attr_comment_content( $attr ) {
	unset( $attr['class'] );

	return $attr;
}
add_filter( 'hybrid_attr_comment-content', 'supernews_attr_comment_content' );

/**
 * Remove role="navigation" from the_posts_pagination()
 */
function supernews_navigation_markup_template( $template ) {
	return str_replace( ' role="navigation"', '', $template );
}
add_filter( 'navigation_markup_template', 'supernews_navigation_markup_template' );
